@@ -1,5 +1,8 @@
 #### "TsparseMatrix" : Virtual class of sparse matrices in triplet-format
 
+setAs("TsparseMatrix", "CsparseMatrix",
+      function(from) .Call("Tsparse_to_Csparse", from, PACKAGE = "Matrix"))
+
 ### "[" :
 ### -----
 
@@ -152,7 +155,3 @@ setMethod("tcrossprod", signature(x = "TsparseMatrix", y = "missing"),
 	  function(x, y = NULL)
 	  .Call("Csparse_crossprod", x, trans = TRUE, triplet = TRUE,
 		PACKAGE = "Matrix"))
-
-setAs("TsparseMatrix", "CsparseMatrix",
-      function(from) .Call("Tsparse_to_Csparse", x, PACKAGE = "Matrix"))
-
