@@ -1,9 +1,13 @@
 #### Logical Sparse Triangular Matrices in Compressed column-oriented format
 
-### contains = "lsparseMatrix"
-
 setAs("ltCMatrix", "matrix",
-      function(from) as(as(from, "dtCMatrix"), "matrix"))
+      function(from) as(as(from, "lgCMatrix"), "matrix"))
+setAs("matrix", "ltCMatrix",
+      function(from) as(as(from, "dtCMatrix"), "ltCMatrix"))
+
+setAs("ltCMatrix", "lgCMatrix",
+      function(from) new("lgCMatrix", i = from@i, p = from@p,
+                         Dim = from@Dim, Dimnames = from@Dimnames))
 
 setAs("ltCMatrix", "dMatrix", # < instead of "dtCMatrix"
       function(from) new("dtCMatrix", i = from@i, p = from@p,
